@@ -13,10 +13,11 @@ class  CLI_helper:
         self.url_token = "https://epg-api.tid.es/api/auth"
         self.username_token = "usu_Evolved5g"
         self.password_token = "evolved5g"
-        self.branch = "evolved5g"
-        self.branch_develop = "develop"
-        self.header = { "content-Type":"application/json", "accept": "application/json", "Authorization": None }
+        self.netapp_branch = "evolved5g"
+        self.branch_cicd_repo = "develop"
+        self.header = { "Content-Type":"application/json", "accept": "application/json", "Authorization": None }
         self.repository = "https://api.github.com/repos/EVOLVED-5G"
+        self.jenkinsjob = "003-NETAPPS/999-ToReview/"
 
     def generate(self, repo_name, package_name, template):
         """Generate EVOLVED-5G compliant NetApp from template"""
@@ -28,14 +29,14 @@ class  CLI_helper:
         # if template:
         #     cookiecutter_generate(template,no_input=no_input,extra_context=extra)
         #     return
-        location = "gh:EVOLVED-5G/NetApp-template" 
+        location = "gh:EVOLVED-5G/NetApp-template"
         directory = "template"
         cookiecutter_generate(location, directory) #extra_context=extra)
 
     def generate_token(self):
 
         self.header = { "content-Type":"application/json", "accept": None, "Authorization": None }
-        data = '{ "username": "usu_Evolved5g", "password": "evolved5g" }'
+        data = '{ "username": "' + self.username_token + '", "password": "' + self.password_token + '" }'
         resp = requests.post(self.url_token, headers=self.header, data=data)
         return(resp.json()["access_token"])
 
@@ -47,14 +48,14 @@ class  CLI_helper:
             try:
                 if mode == "build":
                     self.header = { "content-Type":"application/json", "accept": "application/json", "Authorization": self.generate_token() }
-                    data = '{ "instance": "pro-dcip-evol5-01.hi.inet", "job": "dummy-netapp/'+ mode +'", "parameters": { "VERSION": "1.0", "GIT_URL": "https://github.com/EVOLVED-5G/' + repo +'", "GIT_BRANCH": "' + self.branch + '"} }'
+                    data = '{ "instance": "pro-dcip-evol5-01.hi.inet", "job": "'+self.jenkinsjob + mode+'", "parameters": { "VERSION": "1.0", "GIT_NETAPP_URL": "https://github.com/EVOLVED-5G/' + repo +'", "GIT_NETAPP_BRANCH": "' + self.netapp_branch + '", "GIT_CICD_BRANCH": "' + self.branch_cicd_repo + '"} }'
                     resp = requests.post(self.url_curl, headers=self.header, data=data)
-                    echo(resp.json()["id"])
+                    echo('Your pipeline ID is: %s' % resp.json()["id"])
                 else:
                     self.header = { "content-Type":"application/json", "accept": "application/json", "Authorization": self.generate_token() }
-                    data = '{ "instance": "pro-dcip-evol5-01.hi.inet", "job": "dummy-netapp/'+ mode +'", "parameters": { "VERSION": "1.0", "GIT_URL": "https://github.com/EVOLVED-5G/' + repo +'", "GIT_BRANCH": "' + self.branch_develop + '"} }'
+                    data = '{ "instance": "pro-dcip-evol5-01.hi.inet", "job": "'+self.jenkinsjob + mode+'", "parameters": { "VERSION": "1.0", "GIT_NETAPP_URL": "https://github.com/EVOLVED-5G/' + repo +'", "GIT_NETAPP_BRANCH": "' + self.netapp_branch + '", "GIT_CICD_BRANCH": "' + self.branch_cicd_repo + '"} }'
                     resp = requests.post(self.url_curl, headers=self.header, data=data)
-                    echo(resp.json()["id"])            
+                    echo('Your pipeline ID is: %s' % resp.json()["id"])
             except TypeError as e:
                 echo("Please enter the correct command: evolved5g run_pipeline --mode build --repo REPOSITORY_NAME")
         else:
@@ -84,5 +85,5 @@ class  CLI_helper:
                         echo(element)
         except ValueError as e:
             echo("Please add the ID: evolved5g check-pipeline --id <yourID>")
-   
+
 
